@@ -11,30 +11,29 @@
 #'library(daltoolbox)
 #'library(heimdall)
 #'
-#'# This example assumes a model residual where 1 is an error and 0 is a correct prediction.
+#'# This example uses an error-based drift detector with a synthetic a 
+#'# model residual where 1 is an error and 0 is a correct prediction.
 #'
 #'data(st_drift_examples)
 #'data <- st_drift_examples$univariate
 #'data$event <- NULL
 #'data$prediction <- st_drift_examples$univariate$serie > 4
 #'
-#'
 #'model <- dfr_eddm()
 #'
-#'detection <- c()
-#'output <- list(obj=model, pred=FALSE)
-#'for (i in 1:length(data$serie)){
-#'  output <- update_state(output$obj, data$serie[i])
-#'  if (output$pred){
+#'detection <- NULL
+#'output <- list(obj=model, drift=FALSE)
+#'for (i in 1:length(data$prediction)){
+#'  output <- update_state(output$obj, data$prediction[i])
+#'  if (output$drift){
 #'    type <- 'drift'
 #'    output$obj <- reset_state(output$obj)
 #'  }else{
 #'    type <- ''
 #'  }
-#'  detection <- rbind(detection, list(idx=i, event=output$pred, type=type))
+#'  detection <- rbind(detection, data.frame(idx=i, event=output$drift, type=type))
 #'}
 #'
-#'detection <- as.data.frame(detection)
 #'detection[detection$type == 'drift',]
 #'@export
 dfr_eddm <- function(min_instances=30, min_num_errors=30, warning_level=0.95, out_control_level=0.9) {
@@ -90,14 +89,14 @@ update_state.dfr_eddm <- function(obj, value){
     
     if(state$m_n < state$min_instances){
       obj$state <- state
-      return(list(obj=obj, pred=FALSE))
+      return(list(obj=obj, drift=FALSE))
     }
     
     if(m2s > state$m_m2s_max){
       state$m_m2s_max <- m2s
       
       obj$state <- state
-      return(list(obj=obj, pred=FALSE))
+      return(list(obj=obj, drift=FALSE))
     }
     else{
       p <- m2s / state$m_m2s_max
@@ -115,21 +114,21 @@ update_state.dfr_eddm <- function(obj, value){
         
         obj$drifted <- TRUE
         obj$state <- state
-        return(list(obj=obj, pred=TRUE))
+        return(list(obj=obj, drift=TRUE))
       }
       else if((state$m_num_errors > state$m_min_num_errors) & (p < state$warning_level)){
         obj$state <- state
-        return(list(obj=obj, pred=FALSE))
+        return(list(obj=obj, drift=FALSE))
       }
       else{
         obj$state <- state
-        return(list(obj=obj, pred=FALSE))
+        return(list(obj=obj, drift=FALSE))
       }
     }
   }
   else{
     obj$state <- state
-    return(list(obj=obj, pred=FALSE))
+    return(list(obj=obj, drift=FALSE))
   }
 }
 
