@@ -11,30 +11,27 @@
 #'library(daltoolbox)
 #'library(heimdall)
 #'
-#'# This example assumes a model residual where 1 is an error and 0 is a correct prediction.
+#'# This example uses a dist-based drift detector with a synthetic dataset.
 #'
 #'data(st_drift_examples)
 #'data <- st_drift_examples$univariate
 #'data$event <- NULL
-#'data$prediction <- st_drift_examples$univariate$serie > 4
-#'
 #'
 #'model <- dfr_kldist(target_feat='serie')
 #'
-#'detection <- c()
-#'output <- list(obj=model, pred=FALSE)
+#'detection <- NULL
+#'output <- list(obj=model, drift=FALSE)
 #'for (i in 1:length(data$serie)){
 #'  output <- update_state(output$obj, data$serie[i])
-#'  if (output$pred){
+#'  if (output$drift){
 #'    type <- 'drift'
 #'    output$obj <- reset_state(output$obj)
 #'  }else{
 #'    type <- ''
 #'  }
-#'  detection <- rbind(detection, list(idx=i, event=output$pred, type=type))
+#'  detection <- rbind(detection, data.frame(idx=i, event=output$drift, type=type))
 #'}
 #'
-#'detection <- as.data.frame(detection)
 #'detection[detection$type == 'drift',]
 #'@export
 dfr_kldist <- function(target_feat, window_size=100, p_th=0.9, data=NULL) {
@@ -90,22 +87,22 @@ update_state.dfr_kldist <- function(obj, value) {
       obj$drifted <- TRUE
       
       obj$state <- state
-      return(list(obj=obj, pred=TRUE))
+      return(list(obj=obj, drift=TRUE))
     }
     else{
       state$window <- rbind(state$window, value)
       
       obj$state <- state
-      return(list(obj=obj, pred=FALSE))
+      return(list(obj=obj, drift=FALSE))
     }
   }else{
     state$window <- rbind(state$window, value)
   
     obj$state <- state
-    return(list(obj=obj, pred=FALSE))
+    return(list(obj=obj, drift=FALSE))
   }
   obj$state <- state
-  return(list(obj=obj, pred=obj$drifted))
+  return(list(obj=obj, drift=obj$drifted))
 }
 
 #'@export
